/**
    File: picasa_xml.h
    
    Author: Tero Niemel

*/

#ifndef _PICASA_XML_H_
#define _PICASA_XML_H_

gchar*
picasa_xml_parse_upload_response (gchar *body);

gchar*
picasa_xml_parse_gps_response (gchar *body);

gchar*
picasa_xml_create_metadata_entry (gchar *title, gchar *summary);

gchar*
picasa_xml_create_media_entry (gchar *tags, gchar *gps);


#endif /* _PICASA_XML_H_ */
